@@ -1,13 +1,11 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP Version 7                                                        |
-   +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2018 The PHP Group                                |
+   | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
    | available through the world-wide-web at the following url:           |
-   | http://www.php.net/license/3_01.txt                                  |
+   | https://www.php.net/license/3_01.txt                                 |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -21,43 +19,34 @@
 
 #include "php.h"
 #include "php_spl.h"
-#if HAVE_PCRE || HAVE_BUNDLED_PCRE
 #include "ext/pcre/php_pcre.h"
-#endif
-
-#define spl_ce_Traversable   zend_ce_traversable
-#define spl_ce_Iterator      zend_ce_iterator
-#define spl_ce_Aggregate     zend_ce_aggregate
-#define spl_ce_ArrayAccess   zend_ce_arrayaccess
-#define spl_ce_Serializable  zend_ce_serializable
-#define spl_ce_Countable     zend_ce_countable
 
+extern PHPAPI zend_class_entry *spl_ce_AppendIterator;
+extern PHPAPI zend_class_entry *spl_ce_CachingIterator;
+extern PHPAPI zend_class_entry *spl_ce_CallbackFilterIterator;
+extern PHPAPI zend_class_entry *spl_ce_EmptyIterator;
+extern PHPAPI zend_class_entry *spl_ce_FilterIterator;
+extern PHPAPI zend_class_entry *spl_ce_InfiniteIterator;
+extern PHPAPI zend_class_entry *spl_ce_IteratorIterator;
+extern PHPAPI zend_class_entry *spl_ce_LimitIterator;
+extern PHPAPI zend_class_entry *spl_ce_NoRewindIterator;
+extern PHPAPI zend_class_entry *spl_ce_OuterIterator;
+extern PHPAPI zend_class_entry *spl_ce_ParentIterator;
+extern PHPAPI zend_class_entry *spl_ce_RecursiveCachingIterator;
+extern PHPAPI zend_class_entry *spl_ce_RecursiveCallbackFilterIterator;
+extern PHPAPI zend_class_entry *spl_ce_RecursiveFilterIterator;
 extern PHPAPI zend_class_entry *spl_ce_RecursiveIterator;
 extern PHPAPI zend_class_entry *spl_ce_RecursiveIteratorIterator;
-extern PHPAPI zend_class_entry *spl_ce_RecursiveTreeIterator;
-extern PHPAPI zend_class_entry *spl_ce_FilterIterator;
-extern PHPAPI zend_class_entry *spl_ce_RecursiveFilterIterator;
-extern PHPAPI zend_class_entry *spl_ce_ParentIterator;
-extern PHPAPI zend_class_entry *spl_ce_SeekableIterator;
-extern PHPAPI zend_class_entry *spl_ce_LimitIterator;
-extern PHPAPI zend_class_entry *spl_ce_CachingIterator;
-extern PHPAPI zend_class_entry *spl_ce_RecursiveCachingIterator;
-extern PHPAPI zend_class_entry *spl_ce_OuterIterator;
-extern PHPAPI zend_class_entry *spl_ce_IteratorIterator;
-extern PHPAPI zend_class_entry *spl_ce_NoRewindIterator;
-extern PHPAPI zend_class_entry *spl_ce_InfiniteIterator;
-extern PHPAPI zend_class_entry *spl_ce_EmptyIterator;
-extern PHPAPI zend_class_entry *spl_ce_AppendIterator;
-extern PHPAPI zend_class_entry *spl_ce_RegexIterator;
 extern PHPAPI zend_class_entry *spl_ce_RecursiveRegexIterator;
-extern PHPAPI zend_class_entry *spl_ce_CallbackFilterIterator;
-extern PHPAPI zend_class_entry *spl_ce_RecursiveCallbackFilterIterator;
+extern PHPAPI zend_class_entry *spl_ce_RecursiveTreeIterator;
+extern PHPAPI zend_class_entry *spl_ce_RegexIterator;
+extern PHPAPI zend_class_entry *spl_ce_SeekableIterator;
 
 PHP_MINIT_FUNCTION(spl_iterators);
 
-PHP_FUNCTION(iterator_to_array);
-PHP_FUNCTION(iterator_count);
 PHP_FUNCTION(iterator_apply);
+PHP_FUNCTION(iterator_count);
+PHP_FUNCTION(iterator_to_array);
 
 typedef enum {
 	DIT_Default = 0,
@@ -71,10 +60,8 @@ typedef enum {
 	DIT_NoRewindIterator,
 	DIT_InfiniteIterator,
 	DIT_AppendIterator,
-#if HAVE_PCRE || HAVE_BUNDLED_PCRE
 	DIT_RegexIterator,
 	DIT_RecursiveRegexIterator,
-#endif
 	DIT_CallbackFilterIterator,
 	DIT_RecursiveCallbackFilterIterator,
 	DIT_Unknown = ~0
@@ -142,7 +129,7 @@ typedef struct _spl_dual_it_object {
 		} limit;
 		struct {
 			zend_long             flags; /* CIT_* */
-			zval             zstr;
+			zend_string          *zstr;
 			zval             zchildren;
 			zval             zcache;
 		} caching;
@@ -150,7 +137,6 @@ typedef struct _spl_dual_it_object {
 			zval                  zarrayit;
 			zend_object_iterator *iterator;
 		} append;
-#if HAVE_PCRE || HAVE_BUNDLED_PCRE
 		struct {
 			zend_long        flags;
 			zend_long        preg_flags;
@@ -159,7 +145,6 @@ typedef struct _spl_dual_it_object {
 			regex_mode       mode;
 			int              use_flags;
 		} regex;
-#endif
 		_spl_cbfilter_it_intern *cbfilter;
 	} u;
 	zend_object              std;
@@ -176,12 +161,3 @@ typedef int (*spl_iterator_apply_func_t)(zend_object_iterator *iter, void *puser
 PHPAPI int spl_iterator_apply(zval *obj, spl_iterator_apply_func_t apply_func, void *puser);
 
 #endif /* SPL_ITERATORS_H */
-
-/*
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 4
- * End:
- * vim600: fdm=marker
- * vim: noet sw=4 ts=4
- */
